@@ -39,15 +39,16 @@ from numpy import sqrt, sin, cos, pi
 
 # pylint: disable=unused-import
 try:
-    from typing import Union, Dict, List, Optional
+    from typing import Union, Dict, List, Optional, Tuple, Callable
+    Data = Union["Data1D", "Data2D", "SesansData"]
+    OptArray = Optional[np.ndarray]
+    OptLimits = Optional[Tuple[float, float]]
 except ImportError:
     pass
-else:
-    Data = Union["Data1D", "Data2D", "SesansData"]
 # pylint: enable=unused-import
 
 def load_data(filename, index=0):
-    # type: (str) -> Data
+    # type: (str, int) -> Data
     """
     Load data using a sasview loader.
     """
@@ -139,13 +140,8 @@ class Data1D(object):
 
     *_yaxis*, *_yunit*: label and units for the *y* axis
     """
-    def __init__(self,
-                 x=None,  # type: Optional[np.ndarray]
-                 y=None,  # type: Optional[np.ndarray]
-                 dx=None, # type: Optional[np.ndarray]
-                 dy=None  # type: Optional[np.ndarray]
-                ):
-        # type: (...) -> None
+    def __init__(self, x=None, y=None, dx=None, dy=None):
+        # type: (OptArray, OptArray, OptArray, OptArray) -> None
         self.x, self.y, self.dx, self.dy = x, y, dx, dy
         self.dxl = None
         self.filename = None
@@ -185,7 +181,7 @@ class SesansData(Data1D):
     isSesans = True
     def __init__(self, **kw):
         Data1D.__init__(self, **kw)
-        self.lam = None # type: Optional[np.ndarray]
+        self.lam = None  # type: OptArray
 
 class Data2D(object):
     """
@@ -219,15 +215,8 @@ class Data2D(object):
 
     *x_bins*, *y_bins*: grid steps in *x* and *y* directions
     """
-    def __init__(self,
-                 x=None,   # type: Optional[np.ndarray]
-                 y=None,   # type: Optional[np.ndarray]
-                 z=None,   # type: Optional[np.ndarray]
-                 dx=None,  # type: Optional[np.ndarray]
-                 dy=None,  # type: Optional[np.ndarray]
-                 dz=None   # type: Optional[np.ndarray]
-                ):
-        # type: (...) -> None
+    def __init__(self, x=None, y=None, z=None, dx=None, dy=None, dz=None):
+        # type: (OptArray, OptArray, OptArray, OptArray, OptArray, OptArray) -> None
         self.qx_data, self.dqx_data = x, dx
         self.qy_data, self.dqy_data = y, dy
         self.data, self.err_data = z, dz
@@ -310,7 +299,7 @@ class Sample(object):
         pass
 
 def empty_data1D(q, resolution=0.0, L=0., dL=0.):
-    # type: (np.ndarray, float) -> Data1D
+    # type: (np.ndarray, float, float, float) -> Data1D
     r"""
     Create empty 1D data using the given *q* as the x value.
 
@@ -342,7 +331,7 @@ def empty_data1D(q, resolution=0.0, L=0., dL=0.):
 
 
 def empty_data2D(qx, qy=None, resolution=0.0):
-    # type: (np.ndarray, Optional[np.ndarray], float) -> Data2D
+    # type: (np.ndarray, OptArray, float) -> Data2D
     """
     Create empty 2D data using the given mesh.
 
@@ -384,7 +373,7 @@ def empty_data2D(qx, qy=None, resolution=0.0):
 
 
 def plot_data(data, view=None, limits=None):
-    # type: (Data, str, Optional[Tuple[float, float]]) -> None
+    # type: (Data, str, OptLimits) -> None
     """
     Plot data loaded by the sasview loader.
 
@@ -406,15 +395,9 @@ def plot_data(data, view=None, limits=None):
         _plot_result1D(data, None, None, view, use_data=True, limits=limits)
 
 
-def plot_theory(data,          # type: Data
-                theory,        # type: Optional[np.ndarray]
-                resid=None,    # type: Optional[np.ndarray]
-                view=None,    # type: str
-                use_data=True, # type: bool
-                limits=None,   # type: Optional[np.ndarray]
-                Iq_calc=None   # type: Optional[np.ndarray]
-               ):
-    # type: (...) -> None
+def plot_theory(data, theory, resid=None, view=None, use_data=True,
+                limits=None, Iq_calc=None):
+    # type: (Data, OptArray, OptArray, str, bool, OptLimits, OptArray) -> None
     """
     Plot theory calculation.
 
@@ -460,15 +443,9 @@ def protect(func):
 
 
 @protect
-def _plot_result1D(data,         # type: Data1D
-                   theory,       # type: Optional[np.ndarray]
-                   resid,        # type: Optional[np.ndarray]
-                   view,         # type: str
-                   use_data,     # type: bool
-                   limits=None,  # type: Optional[Tuple[float, float]]
-                   Iq_calc=None  # type: Optional[np.ndarray]
-                  ):
-    # type: (...) -> None
+def _plot_result1D(data, theory, resid, view, use_data,
+                   limits=None, Iq_calc=None):
+    # type: (Data1D, OptArray, OptArray, str, bool, OptLimits, OptArray) -> None
     """
     Plot the data and residuals for 1D data.
     """
@@ -566,13 +543,8 @@ def _plot_result1D(data,         # type: Data1D
 
 
 @protect
-def _plot_result_sesans(data,        # type: SesansData
-                        theory,      # type: Optional[np.ndarray]
-                        resid,       # type: Optional[np.ndarray]
-                        use_data,    # type: bool
-                        limits=None  # type: Optional[Tuple[float, float]]
-                       ):
-    # type: (...) -> None
+def _plot_result_sesans(data, theory, resid, use_data, limits=None):
+    # type: (SesansData, OptArray, OptArray, bool, OptLimits) -> None
     """
     Plot SESANS results.
     """
@@ -616,14 +588,8 @@ def _plot_result_sesans(data,        # type: SesansData
 
 
 @protect
-def _plot_result2D(data,         # type: Data2D
-                   theory,       # type: Optional[np.ndarray]
-                   resid,        # type: Optional[np.ndarray]
-                   view,         # type: str
-                   use_data,     # type: bool
-                   limits=None   # type: Optional[Tuple[float, float]]
-                  ):
-    # type: (...) -> None
+def _plot_result2D(data, theory, resid, view, use_data, limits=None):
+    # type: (Data2D, OptArray, OptArray, str, bool, OptLimits) -> None
     """
     Plot the data and residuals for 2D data.
     """
@@ -637,7 +603,7 @@ def _plot_result2D(data,         # type: Data2D
 
     # Put theory and data on a common colormap scale
     vmin, vmax = np.inf, -np.inf
-    target = None # type: Optional[np.ndarray]
+    target = None  # type: OptArray
     if use_data:
         target = data.data[~data.mask]
         datamin = target[target > 0].min() if view == 'log' else target.min()
@@ -685,13 +651,8 @@ def _plot_result2D(data,         # type: Data2D
 
 
 @protect
-def _plot_2d_signal(data,       # type: Data2D
-                    signal,     # type: np.ndarray
-                    vmin=None,  # type: Optional[float]
-                    vmax=None,  # type: Optional[float]
-                    view=None,  # type: str
-                   ):
-    # type: (...) -> Tuple[float, float]
+def _plot_2d_signal(data, signal, vmin=None, vmax=None, view=None):
+    # type: (Data2D, np.ndarray, Optional[float], Optional[float], str) -> Tuple[float, float]
     """
     Plot the target value for the data.  This could be the data itself,
     the theory calculation, or the residuals.
@@ -737,7 +698,7 @@ def _plot_2d_signal(data,       # type: Data2D
     else:
         vmin_scaled, vmax_scaled = vmin, vmax
     #nx, ny = len(data.x_bins), len(data.y_bins)
-    x_bins, y_bins, image = _build_matrix(data, plottable)
+    _, _, image = _build_matrix(data, plottable)
     plt.imshow(image,
                interpolation='nearest', aspect=1, origin='lower',
                extent=[xmin, xmax, ymin, ymax],
@@ -758,8 +719,8 @@ def _build_matrix(self, plottable):
 
     """
     # No qx or qy given in a vector format
-    if self.qx_data is None or self.qy_data is None \
-            or self.qx_data.ndim != 1 or self.qy_data.ndim != 1:
+    if (self.qx_data is None or self.qy_data is None
+            or self.qx_data.ndim != 1 or self.qy_data.ndim != 1):
         return self.x_bins, self.y_bins, plottable
 
     # maximum # of loops to fillup_pixels
@@ -776,15 +737,13 @@ def _build_matrix(self, plottable):
     weights_data = np.ones([self.data.size])
     # get histogram of ones w/len(data); this will provide
     #the weights of data on each bins
-    weights, xedges, yedges = np.histogram2d(x=self.qy_data,
-                                             y=self.qx_data,
-                                             bins=[y_bins, x_bins],
-                                             weights=weights_data)
+    weights, _, _ = np.histogram2d(
+        x=self.qy_data, y=self.qx_data, bins=[y_bins, x_bins],
+        weights=weights_data)
     # get histogram of data, all points into a bin in a way of summing
-    image, xedges, yedges = np.histogram2d(x=self.qy_data,
-                                           y=self.qx_data,
-                                           bins=[y_bins, x_bins],
-                                           weights=plottable)
+    image, _, _ = np.histogram2d(
+        x=self.qy_data, y=self.qx_data, bins=[y_bins, x_bins],
+        weights=plottable)
     # Now, normalize the image by weights only for weights>1:
     # If weight == 1, there is only one data point in the bin so
     # that no normalization is required.
@@ -857,57 +816,54 @@ def _fillup_pixels(image=None, weights=None):
     :return: image (2d array )
 
     :TODO: Find better way to do for-loop below
-
     """
     # No image matrix given
-    if image is None or np.ndim(image) != 2 \
-            or np.isfinite(image).all() \
-            or weights is None:
+    if (image is None or np.ndim(image) != 2
+            or np.isfinite(image).all()
+            or weights is None):
         return image
     # Get bin size in y and x directions
-    len_y = len(image)
-    len_x = len(image[1])
+    len_x, len_y = image.shape[1], image.shape[0]
     temp_image = np.zeros([len_y, len_x])
     weit = np.zeros([len_y, len_x])
     # do for-loop for all pixels
-    for n_y in range(len(image)):
-        for n_x in range(len(image[1])):
+    for n_y in range(len_y):
+        for n_x in range(len_x):
             # find only null pixels
             if weights[n_y][n_x] > 0 or np.isfinite(image[n_y][n_x]):
                 continue
-            else:
-                # find 4 nearest neighbors
-                # check where or not it is at the corner
-                if n_y != 0 and np.isfinite(image[n_y - 1][n_x]):
-                    temp_image[n_y][n_x] += image[n_y - 1][n_x]
-                    weit[n_y][n_x] += 1
-                if n_x != 0 and np.isfinite(image[n_y][n_x - 1]):
-                    temp_image[n_y][n_x] += image[n_y][n_x - 1]
-                    weit[n_y][n_x] += 1
-                if n_y != len_y - 1 and np.isfinite(image[n_y + 1][n_x]):
-                    temp_image[n_y][n_x] += image[n_y + 1][n_x]
-                    weit[n_y][n_x] += 1
-                if n_x != len_x - 1 and np.isfinite(image[n_y][n_x + 1]):
-                    temp_image[n_y][n_x] += image[n_y][n_x + 1]
-                    weit[n_y][n_x] += 1
-                # go 4 next nearest neighbors when no non-zero
-                # neighbor exists
-                if n_y != 0 and n_x != 0 and \
-                        np.isfinite(image[n_y - 1][n_x - 1]):
-                    temp_image[n_y][n_x] += image[n_y - 1][n_x - 1]
-                    weit[n_y][n_x] += 1
-                if n_y != len_y - 1 and n_x != 0 and \
-                        np.isfinite(image[n_y + 1][n_x - 1]):
-                    temp_image[n_y][n_x] += image[n_y + 1][n_x - 1]
-                    weit[n_y][n_x] += 1
-                if n_y != len_y and n_x != len_x - 1 and \
-                        np.isfinite(image[n_y - 1][n_x + 1]):
-                    temp_image[n_y][n_x] += image[n_y - 1][n_x + 1]
-                    weit[n_y][n_x] += 1
-                if n_y != len_y - 1 and n_x != len_x - 1 and \
-                        np.isfinite(image[n_y + 1][n_x + 1]):
-                    temp_image[n_y][n_x] += image[n_y + 1][n_x + 1]
-                    weit[n_y][n_x] += 1
+            # find 4 nearest neighbors
+            # check where or not it is at the corner
+            if n_y != 0 and np.isfinite(image[n_y - 1][n_x]):
+                temp_image[n_y][n_x] += image[n_y - 1][n_x]
+                weit[n_y][n_x] += 1
+            if n_x != 0 and np.isfinite(image[n_y][n_x - 1]):
+                temp_image[n_y][n_x] += image[n_y][n_x - 1]
+                weit[n_y][n_x] += 1
+            if n_y != len_y - 1 and np.isfinite(image[n_y + 1][n_x]):
+                temp_image[n_y][n_x] += image[n_y + 1][n_x]
+                weit[n_y][n_x] += 1
+            if n_x != len_x - 1 and np.isfinite(image[n_y][n_x + 1]):
+                temp_image[n_y][n_x] += image[n_y][n_x + 1]
+                weit[n_y][n_x] += 1
+            # go 4 next nearest neighbors when no non-zero
+            # neighbor exists
+            if (n_y != 0 and n_x != 0
+                    and np.isfinite(image[n_y - 1][n_x - 1])):
+                temp_image[n_y][n_x] += image[n_y - 1][n_x - 1]
+                weit[n_y][n_x] += 1
+            if (n_y != len_y - 1 and n_x != 0
+                    and np.isfinite(image[n_y + 1][n_x - 1])):
+                temp_image[n_y][n_x] += image[n_y + 1][n_x - 1]
+                weit[n_y][n_x] += 1
+            if (n_y != len_y and n_x != len_x - 1
+                    and np.isfinite(image[n_y - 1][n_x + 1])):
+                temp_image[n_y][n_x] += image[n_y - 1][n_x + 1]
+                weit[n_y][n_x] += 1
+            if (n_y != len_y - 1 and n_x != len_x - 1
+                    and np.isfinite(image[n_y + 1][n_x + 1])):
+                temp_image[n_y][n_x] += image[n_y + 1][n_x + 1]
+                weit[n_y][n_x] += 1
 
     # get it normalized
     ind = (weit > 0)
