@@ -42,10 +42,13 @@ but where the $q$ vector is redefined as
 References
 ----------
 
-#.  O Glatter and O Kratky (editors), *Small Angle X-ray Scattering*, Academic Press, (1982) Page 404
-#.  J S Higgins, H C Benoit, *Polymers and Neutron Scattering*, Oxford Science Publications, (1996)
-#.  S M King, *Small Angle Neutron Scattering* in *Modern Techniques for Polymer Characterisation*, Wiley, (1999)
-#.  http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
+#. O Glatter and O Kratky (editors), *Small Angle X-ray Scattering*,
+   Academic Press, (1982) Page 404
+#. J S Higgins, H C Benoit, *Polymers and Neutron Scattering*,
+   Oxford Science Publications, (1996)
+#. S M King, *Small Angle Neutron Scattering*
+   in *Modern Techniques for Polymer Characterisation*, Wiley, (1999)
+#. http://www.ncnr.nist.gov/staff/hammouda/distance_learning/chapter_28.pdf
 
 Authorship and Verification
 ----------------------------
